#!/bin/sh
#
# Copyright (c) 2019 Vivotek Inc. All rights reserved.
#
# +-----------------------------------------------------------------+
# | THIS SOFTWARE IS FURNISHED UNDER A LICENSE AND MAY ONLY BE USED |
# | AND COPIED IN ACCORDANCE WITH THE TERMS AND CONDITIONS OF SUCH  |
# | A LICENSE AND WITH THE INCLUSION OF THE THIS COPY RIGHT NOTICE. |
# | THIS SOFTWARE OR ANY OTHER COPIES OF THIS SOFTWARE MAY NOT BE   |
# | PROVIDED OR OTHERWISE MADE AVAILABLE TO ANY OTHER PERSON. THE   |
# | OWNERSHIP AND TITLE OF THIS SOFTWARE IS NOT TRANSFERRED.        |
# |                                                                 |
# | THE INFORMATION IN THIS SOFTWARE IS SUBJECT TO CHANGE WITHOUT   |
# | ANY PRIOR NOTICE AND SHOULD NOT BE CONSTRUED AS A COMMITMENT BY |
# | VIVOTEK INC.                                                    |
# +-----------------------------------------------------------------+
#
# Date: 2019-05-29 06:22:19
# Author: Jacko Chang (jacko.chang@vivotek.com)
#

if [ -z "${PKGROOT}" ]; then
	PKGROOT=$(realpath ./)
fi

if [ "$(which jq; echo $?)" != "0" ];then
	export PATH=${PKGROOT}/bin:${PATH}
	export LD_LIBRARY_PATH=${PKGROOT}/lib
fi

cd /

# device id
DEVICE=$(jq -r '.iotbus.clientid' ${PKGROOT}/config.json)
[ -z "${DEVICE}" ] &&	exit 0

# timezone
TZ=$(confclient -p 99 -t Value -g system_timezoneindex)
TZ=$(($TZ - $TZ%10))

# daylight saving time
DST=0
[ "$(confclient -p 99 -t Value -g system_daylight_dstactualmode)" == "3" ] && DST=1

# utc time convert
TS=$(date +%s)
UTC=$(($TS - $(($TZ * 90)) - $DST * 3600 ))

# time format
TF=0x0001

FMT() {
	date +%Y%m%d_%H%M%S -D %s -d $1
}

FMT_S() {
	if [ $TF == "0x0001" ]; then
		echo "At $(date +%H:%M -D %s -d $1)"
	elif [ $TF == "0x0002" ]; then
		echo "$(date +%H時%M分 -D %s -d $1)"
	fi
}

# event name
case $1 in
	boot)
		EVENT="Camera just rebooted";;
	smartsd)
		EVENT="SD card lifetime warning";;
	0|1|2)
		EVENT="$(confclient -p 99 -t Value -g event_i${1}_name)";;
	*)
		exit 1
esac

# hostname
HOST=$(confclient -p 99 -t Value -g system_hostname)

# is recording?
MSGTYPE=3
ACTION_ENABLE=$(confclient -p 99 -t Value -g event_i${1}_action_cf_enable)
[ -d /mnt/auto/CF/ ] && RECORDING=`lsof | grep CF | grep mp4`
if [ ! -z "$RECORDING" ]; then
	MSGTYPE=2
elif [ "${ACTION_ENABLE}" = "1" ]; then
	ACTION_MEDIA=$(confclient -p 99 -t Value -g event_i${1}_action_cf_media)
	MEDIA_TYPE=$(confclient -p 99 -t Value -g media_i${ACTION_MEDIA}_type)
	if [ "${MEDIA_TYPE}" = "videoclip" ]; then
		MSGTYPE=2
	fi
fi

cat << EOF | jq -n -f /dev/stdin | ${PKGROOT}/bin/mosquitto_pub -p 8883 -t 'things/shadow/update' -s
.forwardEventMsg="$EVENT, $(FMT_S $TS), $HOST" |
.localTime="$(FMT $TS)" |
.utcTime="$(FMT $UTC)" |
.msgType=$MSGTYPE |
.p2pType=2 |
.deviceId="$DEVICE" |
{ state: { reported: . } }
EOF

cd -
echo "$EVENT at UTC $(FMT $TS), $HOST, IoTbus daemon pid is $(pgrep -f iotbus)" >> ${PKGROOT}/iot.log
exit 0

