#!/bin/sh
#
# Copyright (c) 2018 Vivotek Inc. All rights reserved.
#
# +-----------------------------------------------------------------+
# | THIS SOFTWARE IS FURNISHED UNDER A LICENSE AND MAY ONLY BE USED |
# | AND COPIED IN ACCORDANCE WITH THE TERMS AND CONDITIONS OF SUCH  |
# | A LICENSE AND WITH THE INCLUSION OF THE THIS COPY RIGHT NOTICE. |
# | THIS SOFTWARE OR ANY OTHER COPIES OF THIS SOFTWARE MAY NOT BE   |
# | PROVIDED OR OTHERWISE MADE AVAILABLE TO ANY OTHER PERSON. THE   |
# | OWNERSHIP AND TITLE OF THIS SOFTWARE IS NOT TRANSFERRED.        |
# |                                                                 |
# | THE INFORMATION IN THIS SOFTWARE IS SUBJECT TO CHANGE WITHOUT   |
# | ANY PRIOR NOTICE AND SHOULD NOT BE CONSTRUED AS A COMMITMENT BY |
# | VIVOTEK INC.                                                    |
# +-----------------------------------------------------------------+
#
# Date: 2019-01-11 17:45:14
# Author: Ben Chuang (ben.chuang@vivotek.com)
#

if [ -z "${PKGROOT}" ]; then
	PKGROOT=$(realpath ./)
fi

export PATH=${PKGROOT}/bin:${PATH}
export LD_LIBRARY_PATH=${PKGROOT}/lib

PKGCONF=${PKGROOT}/config.json
DEFAULTCONF=${PKGROOT}/default.json
VIDEOSECTOR=$(confclient -p 99 -t Value -g capability_nmediastream)
AUDIOSECTOR=$(confclient -p 99 -t Value -g capability_naudioin)
BLOCKINDEX=0


updatestream()
{
	[ ! -f ${DEFAULTCONF} ] && exit 0

	if [ ${VIDEOSECTOR} -ne 0 ]; then
		BLOCKINDEX=$((BLOCKINDEX+1))
	fi

	if [ ${AUDIOSECTOR} -ne 0 ]; then
		BLOCKINDEX=$((BLOCKINDEX+1))
	fi

	cat <<- EOF | jq -s '.[0] * .[1]' ${DEFAULTCONF} - > ${DEFAULTCONF}~
	{
		"cloudrecd": {
			"streaming": {
				"videoSector": ${VIDEOSECTOR},
				"audioSector": ${AUDIOSECTOR},
				"blockIndex": ${BLOCKINDEX}
			}
		}
	}
	EOF

	mv ${DEFAULTCONF}~ ${DEFAULTCONF}
}

updateconf()
{
	updatestream

	[ ! -f ${PKGCONF} ] && exit 0

	TEMP_DEFAULIT_VAL=$(mktemp -p ${PKGROOT} param-XXXXXX)
	jq -r '[.vivocloud.apiserver, .vivocloud.config, .cloudrecd.logPath, .cloudrecd.recordingPath, .cloudrecd.storageClass, .cloudrecd.streaming.videoSector, .cloudrecd.streaming.audioSector, .cloudrecd.streaming.blockIndex, .cloudrecd.streaming.streamIndex] | map(tostring) | join("|")' ${PKGROOT}/default.json > ${TEMP_DEFAULIT_VAL}
	IFS="|" read API_SERVER CONFIG_URL LOGPATH RECORDING_PATH STORAGE_ClASS VIDEO_SECTOR AUDIO_SECTOR BLOCK_INDEX STREAM_INDEX < ${TEMP_DEFAULIT_VAL}
	rm -f ${TEMP_DEFAULIT_VAL}

	TEMP_CONFIG_VAL=$(mktemp -p ${PKGROOT} param-XXXXXX)
	jq -r '[.vivocloud.apiserver, .vivocloud.config] | map(tostring) | join("|")' ${PKGCONF} > ${TEMP_CONFIG_VAL}
	IFS="|" read CUR_API_SERVER CUR_CONFIG_URL < ${TEMP_CONFIG_VAL}
	rm -f ${TEMP_CONFIG_VAL}

	PROTOCOL="https://"

	[ "${CUR_API_SERVER}" = "${PROTOCOL}qa-${API_SERVER:${#PROTOCOL}}" ] && API_SERVER=${CUR_API_SERVER}
	[ "${CUR_CONFIG_URL}" = "${PROTOCOL}qa-${CONFIG_URL:${#PROTOCOL}}" ] && CONFIG_URL=${CUR_CONFIG_URL}

	cat <<- EOF | jq -s '.[0] * .[1]' ${PKGCONF} - > ${PKGCONF}~
	{
		"vivocloud": {
			"apiserver": "${API_SERVER}",
			"config": "${CONFIG_URL}"
		},
		"cloudrecd": {
			"logPath": "${LOGPATH}",
			"recordingPath": "${RECORDING_PATH}",
			"storageClass": "${STORAGE_ClASS}",
			"streaming":{
				"videoSector": ${VIDEO_SECTOR},
				"audioSector": ${AUDIO_SECTOR},
				"blockIndex": ${BLOCK_INDEX},
				"streamIndex": ${STREAM_INDEX}
			}
		}
	}
	EOF

	mv ${PKGCONF}~ ${PKGCONF}
}

updatelinker()
{
	if [ -d ${PKGROOT}/ssl/ring ]; then
		INITS=$(find ${PKGROOT}/ssl/ring -type l)
		for i in ${INITS}; do
			linkpath=$(readlink ${i})
			if [ ! -f ${linkpath} ]; then
				return
			fi
			linkname=$(basename ${linkpath})
			if [ "${linkname}" == "IoTPrivateKey.pem" ]; then
				ln -fs ${PKGROOT}/ssl/awsiot/${linkname} ${i}
			else
				ln -fs ${PKGROOT}/ssl/ring/${linkname} ${i}
			fi
		done
	fi
}


cd /
ACTION=${1}
case ${ACTION} in
	install)
		updateconf
		updatelinker
		;;
esac
cd -
exit 0